@@ -30,8 +30,12 @@ MOBILE_OS_FAMILIES = (
 )
 
 MOBILE_BROWSER_FAMILIES = (
+    'IE Mobile',
     'Opera Mobile',
     'Opera Mini',
+    'Chrome Mobile',
+    'Chrome Mobile WebView',
+    'Chrome Mobile iOS',
 )
 
 TABLET_DEVICE_FAMILIES = (
@@ -136,10 +140,11 @@ class UserAgent(object):
         self.device = parse_device(**ua_dict['device'])
 
     def __str__(self):
-        device = self.is_pc and "PC" or self.device.family
-        os = ("%s %s" % (self.os.family, self.os.version_string)).strip()
-        browser = ("%s %s" % (self.browser.family, self.browser.version_string)).strip()
-        return " / ".join([device, os, browser])
+        return "{device} / {os} / {browser}".format(
+            device=self.get_device(),
+            os=self.get_os(),
+            browser=self.get_browser()
+        )
 
     def __unicode__(self):
         return unicode(str(self))
@@ -159,10 +164,17 @@ class UserAgent(object):
             return True
         if 'Blackberry 95' in self.device.family:  # BB Storm devices
             return True
-        if 'Blackberry 95' in self.device.family:  # BB Torch devices
-            return True
         return False
 
+    def get_device(self):
+        return self.is_pc and "PC" or self.device.family
+
+    def get_os(self):
+        return ("%s %s" % (self.os.family, self.os.version_string)).strip()
+
+    def get_browser(self):
+        return ("%s %s" % (self.browser.family, self.browser.version_string)).strip()
+
     @property
     def is_tablet(self):
         if self.device.family in TABLET_DEVICE_FAMILIES:
@@ -215,7 +227,7 @@ class UserAgent(object):
         if self.device.family in TOUCH_CAPABLE_DEVICE_FAMILIES:
             return True
         if self.os.family == 'Windows':
-            if self.os.version_string.startswith('RT'):
+            if self.os.version_string.startswith(('RT', 'CE')):
                 return True
             if self.os.version_string.startswith('8') and 'Touch' in self.ua_string:
                 return True
@@ -251,5 +263,6 @@ class UserAgent(object):
             return True
         return False
 
+
 def parse(user_agent_string):
     return UserAgent(user_agent_string)
